# Spark MLlib runtime for MLServer

This package provides a MLServer runtime compatible with Spark MLlib.

## Usage

You can install the runtime, alongside `mlserver`, as:

```bash
pip install mlserver mlserver-mllib
```

For further information on how to use MLServer with Spark MLlib, you can check
out the [github.com/SeldonIO/MLServer
repository](https://github.com/SeldonIO/MLServer).
